@@ -1,20 +1,20 @@
 /*  zint.h - definitions for libzint
 
     libzint - the open source barcode library
-    Copyright (C) 2009-2017 Robin Stuart <rstuart114@gmail.com>
+    Copyright (C) 2009-2018 Robin Stuart <rstuart114@gmail.com>
 
     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions
     are met:
 
-    1. Redistributions of source code must retain the above copyright 
-       notice, this list of conditions and the following disclaimer.  
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
     2. Redistributions in binary form must reproduce the above copyright
        notice, this list of conditions and the following disclaimer in the
-       documentation and/or other materials provided with the distribution.  
+       documentation and/or other materials provided with the distribution.
     3. Neither the name of the project nor the names of its contributors
        may be used to endorse or promote products derived from this software
-       without specific prior written permission. 
+       without specific prior written permission.
 
     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -25,7 +25,7 @@
     OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
     HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
     LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-    OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
+    OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
     SUCH DAMAGE.
  */
 
@@ -40,6 +40,12 @@ extern "C" {
         float x, y, length, width;
         struct zint_render_line *next; /* Pointer to next line */
     };
+    
+    struct zint_vector_rect {
+        float x, y, height, width;
+        int colour;
+        struct zint_vector_rect *next;
+    };
 
     struct zint_render_string {
         float x, y, fsize;
@@ -48,17 +54,36 @@ extern "C" {
         unsigned char *text;
         struct zint_render_string *next; /* Pointer to next character */
     };
+    
+    struct zint_vector_string {
+        float x, y, fsize;
+        float width; /* Suggested string width, may be 0 if none recommended */
+        int length;
+        unsigned char *text;
+        struct zint_vector_string *next; /* Pointer to next character */
+    };
 
     struct zint_render_ring {
         float x, y, radius, line_width;
         struct zint_render_ring *next; /* Pointer to next ring */
     };
 
+    struct zint_vector_circle {
+        float x, y, diameter;
+        int colour;
+        struct zint_vector_circle *next; /* Pointer to next circle */
+    };
+    
     struct zint_render_hexagon {
-        float x, y;
+        float x, y, height;
         struct zint_render_hexagon *next; /* Pointer to next hexagon */
     };
 
+    struct zint_vector_hexagon {
+        float x, y, diameter;
+        struct zint_vector_hexagon *next; /* Pointer to next hexagon */
+    };
+    
     struct zint_render {
         float width, height;
         struct zint_render_line *lines; /* Pointer to first line */
@@ -66,6 +91,14 @@ extern "C" {
         struct zint_render_ring *rings; /* Pointer to first ring */
         struct zint_render_hexagon *hexagons; /* Pointer to first hexagon */
     };
+    
+    struct zint_vector {
+        float width, height;
+        struct zint_vector_rect *rectangles; /* Pointer to first rectangle */
+        struct zint_vector_hexagon *hexagons; /* Pointer to first hexagon */
+        struct zint_vector_string *strings; /* Points to first string */
+        struct zint_vector_circle *circles; /* Points to first circle */
+    };
 
     struct zint_symbol {
         int symbology;
@@ -81,6 +114,7 @@ extern "C" {
         int option_2;
         int option_3;
         int show_hrt;
+        int fontsize;
         int input_mode;
         int eci;
         unsigned char text[128];
@@ -95,14 +129,15 @@ extern "C" {
         int bitmap_height;
         unsigned int bitmap_byte_length;
         float dot_size;
+        struct zint_vector *vector;
         struct zint_render *rendered;
         int debug;
     };
 
 #define ZINT_VERSION_MAJOR      2
 #define ZINT_VERSION_MINOR      6
-#define ZINT_VERSION_RELEASE    1
-    
+#define ZINT_VERSION_RELEASE    6
+
     /* Tbarcode 7 codes */
 #define BARCODE_CODE11		1
 #define BARCODE_C25MATRIX	2
@@ -151,6 +186,7 @@ extern "C" {
 #define BARCODE_RM4SCC		70
 #define BARCODE_DATAMATRIX	71
 #define BARCODE_EAN14		72
+#define BARCODE_VIN             73
 #define BARCODE_CODABLOCKF	74
 #define BARCODE_NVE18		75
 #define BARCODE_JAPANPOST	76
@@ -180,10 +216,13 @@ extern "C" {
 #define BARCODE_HIBC_MICPDF	108
 #define BARCODE_HIBC_BLOCKF	110
 #define BARCODE_HIBC_AZTEC	112
-    
+
     /* Tbarcode 10 codes */
 #define BARCODE_DOTCODE         115
 #define BARCODE_HANXIN          116
+    
+    /*Tbarcode 11 codes*/
+#define BARCODE_MAILMARK        121
 
     /* Zint specific */
 #define BARCODE_AZRUNE		128
@@ -202,6 +241,7 @@ extern "C" {
 #define BARCODE_CODEONE		141
 #define BARCODE_GRIDMATRIX	142
 #define BARCODE_UPNQR           143
+#define BARCODE_ULTRA       144
 
 // Output options
 #define BARCODE_NO_ASCII	1
@@ -213,13 +253,13 @@ extern "C" {
 #define BOLD_TEXT               64
 #define CMYK_COLOUR             128
 #define BARCODE_DOTTY_MODE      256
+#define GS1_GS_SEPARATOR        512
 
 // Input data types
 #define DATA_MODE	0
 #define UNICODE_MODE	1
 #define GS1_MODE	2
-#define KANJI_MODE	3
-#define SJIS_MODE	4
+#define ESCAPE_MODE     8
 
 // Data Matrix specific options
 #define DM_SQUARE	100
@@ -235,9 +275,12 @@ extern "C" {
 #define ZINT_ERROR_ENCODING_PROBLEM	9
 #define ZINT_ERROR_FILE_ACCESS	        10
 #define ZINT_ERROR_MEMORY		11
-    
+
 // Raster file types
 #define OUT_BUFFER          0
+#define OUT_SVG_FILE        10
+#define OUT_EPS_FILE        20
+#define OUT_EMF_FILE        30
 #define	OUT_PNG_FILE        100
 #define	OUT_BMP_FILE        120
 #define OUT_GIF_FILE        140
@@ -254,14 +297,14 @@ extern "C" {
 #define ZINT_EXTERN extern
 #endif
 #else
-#define ZINT_EXTERN extern	
+#define ZINT_EXTERN extern
 #endif
 
     ZINT_EXTERN struct zint_symbol *ZBarcode_Create(void);
     ZINT_EXTERN void ZBarcode_Clear(struct zint_symbol *symbol);
     ZINT_EXTERN void ZBarcode_Delete(struct zint_symbol *symbol);
 
-    ZINT_EXTERN int ZBarcode_Encode(struct zint_symbol *symbol, const unsigned char *input, int length);
+    ZINT_EXTERN int ZBarcode_Encode(struct zint_symbol *symbol, const unsigned char *source, int in_length);
     ZINT_EXTERN int ZBarcode_Encode_File(struct zint_symbol *symbol, char *filename);
     ZINT_EXTERN int ZBarcode_Print(struct zint_symbol *symbol, int rotate_angle);
     ZINT_EXTERN int ZBarcode_Encode_and_Print(struct zint_symbol *symbol, unsigned char *input, int length, int rotate_angle);
@@ -270,8 +313,11 @@ extern "C" {
     ZINT_EXTERN int ZBarcode_Render(struct zint_symbol *symbol, const float width, const float height);
 
     ZINT_EXTERN int ZBarcode_Buffer(struct zint_symbol *symbol, int rotate_angle);
+    ZINT_EXTERN int ZBarcode_Buffer_Vector(struct zint_symbol *symbol, int rotate_angle);
     ZINT_EXTERN int ZBarcode_Encode_and_Buffer(struct zint_symbol *symbol, unsigned char *input, int length, int rotate_angle);
+    ZINT_EXTERN int ZBarcode_Encode_and_Buffer_Vector(struct zint_symbol *symbol, unsigned char *input, int length, int rotate_angle);
     ZINT_EXTERN int ZBarcode_Encode_File_and_Buffer(struct zint_symbol *symbol, char *filename, int rotate_angle);
+    ZINT_EXTERN int ZBarcode_Encode_File_and_Buffer_Vector(struct zint_symbol *symbol, char *filename, int rotate_angle);
 
     ZINT_EXTERN int ZBarcode_ValidID(int symbol_id);
     ZINT_EXTERN int ZBarcode_Version();
@@ -281,3 +327,4 @@ extern "C" {
 #endif /* __cplusplus */
 
 #endif /* ZINT_H */
+
